Class: Edgestitch::Railtie

Inherits:
Rails::Railtie
  • Object
show all
Defined in:
lib/edgestitch/railtie.rb

Overview

Railtie to install the stitch task (db:stitch). require this railtie to automatically install the stitch task for the app, or define it manually adding ::Edgestitch.define_stitch to your Rakefile.